@@ -5,6 +5,7 @@ from .collections import (
     BrokerQueue,
     InMemoryBrokerQueue,
     PostgreSqlBrokerQueue,
+    PostgreSqlBrokerQueueBuilder,
 )
 from .dispatchers import (
     BrokerDispatcher,
@@ -15,6 +16,7 @@ from .dispatchers import (
 from .handlers import (
     BrokerHandler,
     BrokerHandlerService,
+    BrokerPort,
 )
 from .messages import (
     REQUEST_HEADERS_CONTEXT_VAR,
@@ -30,6 +32,7 @@ from .pools import (
 )
 from .publishers import (
     BrokerPublisher,
+    BrokerPublisherBuilder,
     BrokerPublisherQueue,
     InMemoryBrokerPublisher,
     InMemoryBrokerPublisherQueue,
@@ -40,12 +43,19 @@ from .publishers import (
 from .subscribers import (
     BrokerSubscriber,
     BrokerSubscriberBuilder,
+    BrokerSubscriberDuplicateValidator,
     BrokerSubscriberQueue,
     BrokerSubscriberQueueBuilder,
+    BrokerSubscriberValidator,
+    FilteredBrokerSubscriber,
     InMemoryBrokerSubscriber,
     InMemoryBrokerSubscriberBuilder,
+    InMemoryBrokerSubscriberDuplicateValidator,
     InMemoryBrokerSubscriberQueue,
     InMemoryBrokerSubscriberQueueBuilder,
+    PostgreSqlBrokerSubscriberDuplicateValidator,
+    PostgreSqlBrokerSubscriberDuplicateValidatorBuilder,
+    PostgreSqlBrokerSubscriberDuplicateValidatorQueryFactory,
     PostgreSqlBrokerSubscriberQueue,
     PostgreSqlBrokerSubscriberQueueBuilder,
     PostgreSqlBrokerSubscriberQueueQueryFactory,
