@@ -10,6 +10,12 @@ from .broker import (
 from .checkers import (
     CheckDecorator,
 )
+from .http import (
+    HttpEnrouteDecorator,
+    RestCommandEnrouteDecorator,
+    RestEnrouteDecorator,
+    RestQueryEnrouteDecorator,
+)
 from .kinds import (
     EnrouteDecoratorKind,
 )
@@ -17,8 +23,3 @@ from .periodic import (
     PeriodicEnrouteDecorator,
     PeriodicEventEnrouteDecorator,
 )
-from .rest import (
-    RestCommandEnrouteDecorator,
-    RestEnrouteDecorator,
-    RestQueryEnrouteDecorator,
-)
