@@ -1,9 +1,6 @@
 from .abc import (
     DiscoveryClient,
 )
-from .kong import (
-    KongDiscoveryClient,
-)
 from .memory import (
     InMemoryDiscoveryClient,
 )
